@@ -6,8 +6,8 @@
 // license terms please see the LICENSE file distributed with this
 // source code.
 
-#include "config.h"
 #include "common.h"
+#include "config.h"
 
 #if defined(_WIN32) && !defined(__MINGW32__)
 #include <windows.h>
@@ -18,9 +18,9 @@
 
 #include <mutex>
 
-#include "llvm/IR/LLVMContext.h"
 #include "llvm/IR/DebugInfo.h"
 #include "llvm/IR/Instruction.h"
+#include "llvm/IR/LLVMContext.h"
 
 #include "Context.h"
 #include "Kernel.h"
@@ -44,8 +44,8 @@ Context::Context()
 {
   m_llvmContext = new llvm::LLVMContext;
 
-  m_globalMemory = new Memory(AddrSpaceGlobal, sizeof(size_t)==8 ? 16 : 8,
-                              this);
+  m_globalMemory =
+    new Memory(AddrSpaceGlobal, sizeof(size_t) == 8 ? 16 : 8, this);
   m_kernelInvocation = NULL;
 
   loadPlugins();
@@ -61,7 +61,7 @@ Context::~Context()
 
 bool Context::isThreadSafe() const
 {
-  for (const PluginEntry &p : m_plugins)
+  for (const PluginEntry& p : m_plugins)
   {
     if (!p.first->isThreadSafe())
       return false;
@@ -97,14 +97,13 @@ void Context::loadPlugins()
   if (checkEnv("OCLGRIND_INTERACTIVE"))
     m_plugins.push_back(make_pair(new InteractiveDebugger(this), true));
 
-
   // Load dynamic plugins
-  const char *dynamicPlugins = getenv("OCLGRIND_PLUGINS");
+  const char* dynamicPlugins = getenv("OCLGRIND_PLUGINS");
   if (dynamicPlugins)
   {
     std::istringstream ss(dynamicPlugins);
     std::string libpath;
-    while(std::getline(ss, libpath, ':'))
+    while (std::getline(ss, libpath, ':'))
     {
 #if defined(_WIN32) && !defined(__MINGW32__)
       HMODULE library = LoadLibraryA(libpath.c_str());
@@ -115,7 +114,7 @@ void Context::loadPlugins()
         continue;
       }
 
-      void *initialize = GetProcAddress(library, "initializePlugins");
+      void* initialize = GetProcAddress(library, "initializePlugins");
       if (!initialize)
       {
         cerr << "Loading Oclgrind plugin failed (GetProcAddress): "
@@ -123,24 +122,23 @@ void Context::loadPlugins()
         continue;
       }
 #else
-      void *library = dlopen(libpath.c_str(), RTLD_NOW);
+      void* library = dlopen(libpath.c_str(), RTLD_NOW);
       if (!library)
       {
-        cerr << "Loading Oclgrind plugin failed (dlopen): "
-             << dlerror() << endl;
+        cerr << "Loading Oclgrind plugin failed (dlopen): " << dlerror()
+             << endl;
         continue;
       }
 
-      void *initialize = dlsym(library, "initializePlugins");
+      void* initialize = dlsym(library, "initializePlugins");
       if (!initialize)
       {
-        cerr << "Loading Oclgrind plugin failed (dlsym): "
-             << dlerror() << endl;
+        cerr << "Loading Oclgrind plugin failed (dlsym): " << dlerror() << endl;
         continue;
       }
 #endif
 
-      ((void(*)(Context*))initialize)(this);
+      ((void (*)(Context*))initialize)(this);
       m_pluginLibraries.push_back(library);
     }
   }
@@ -150,23 +148,23 @@ void Context::unloadPlugins()
 {
   // Release dynamic plugin libraries
   list<void*>::iterator plibItr;
-  for (plibItr = m_pluginLibraries.begin();
-       plibItr != m_pluginLibraries.end(); plibItr++)
+  for (plibItr = m_pluginLibraries.begin(); plibItr != m_pluginLibraries.end();
+       plibItr++)
   {
 #if defined(_WIN32) && !defined(__MINGW32__)
-      void *release = GetProcAddress((HMODULE)*plibItr, "releasePlugins");
-      if (release)
-      {
-        ((void(*)(Context*))release)(this);
-      }
-      FreeLibrary((HMODULE)*plibItr);
+    void* release = GetProcAddress((HMODULE)*plibItr, "releasePlugins");
+    if (release)
+    {
+      ((void (*)(Context*))release)(this);
+    }
+    FreeLibrary((HMODULE)*plibItr);
 #else
-      void *release = dlsym(*plibItr, "releasePlugins");
-      if (release)
-      {
-        ((void(*)(Context*))release)(this);
-      }
-      dlclose(*plibItr);
+    void* release = dlsym(*plibItr, "releasePlugins");
+    if (release)
+    {
+      ((void (*)(Context*))release)(this);
+    }
+    dlclose(*plibItr);
 #endif
   }
 
@@ -181,12 +179,12 @@ void Context::unloadPlugins()
   m_plugins.clear();
 }
 
-void Context::registerPlugin(Plugin *plugin)
+void Context::registerPlugin(Plugin* plugin)
 {
   m_plugins.push_back(make_pair(plugin, false));
 }
 
-void Context::unregisterPlugin(Plugin *plugin)
+void Context::unregisterPlugin(Plugin* plugin)
 {
   m_plugins.remove(make_pair(plugin, false));
 }
@@ -195,31 +193,30 @@ void Context::logError(const char* error) const
 {
   Message msg(ERROR, this);
   msg << error << endl
-      << msg.INDENT
-      << "Kernel: " << msg.CURRENT_KERNEL << endl
+      << msg.INDENT << "Kernel: " << msg.CURRENT_KERNEL << endl
       << "Entity: " << msg.CURRENT_ENTITY << endl
       << msg.CURRENT_LOCATION << endl;
   msg.send();
 }
 
-#define NOTIFY(function, ...)                     \
-{                                                 \
-  PluginList::const_iterator pluginItr;           \
-  for (pluginItr = m_plugins.begin();             \
-       pluginItr != m_plugins.end(); pluginItr++) \
-  {                                               \
-    pluginItr->first->function(__VA_ARGS__);      \
-  }                                               \
-}
+#define NOTIFY(function, ...)                                                  \
+  {                                                                            \
+    PluginList::const_iterator pluginItr;                                      \
+    for (pluginItr = m_plugins.begin(); pluginItr != m_plugins.end();          \
+         pluginItr++)                                                          \
+    {                                                                          \
+      pluginItr->first->function(__VA_ARGS__);                                 \
+    }                                                                          \
+  }
 
-void Context::notifyInstructionExecuted(const WorkItem *workItem,
-                                        const llvm::Instruction *instruction,
+void Context::notifyInstructionExecuted(const WorkItem* workItem,
+                                        const llvm::Instruction* instruction,
                                         const TypedValue& result) const
 {
   NOTIFY(instructionExecuted, workItem, instruction, result);
 }
 
-void Context::notifyKernelBegin(const KernelInvocation *kernelInvocation) const
+void Context::notifyKernelBegin(const KernelInvocation* kernelInvocation) const
 {
   assert(m_kernelInvocation == NULL);
   m_kernelInvocation = kernelInvocation;
@@ -227,7 +224,7 @@ void Context::notifyKernelBegin(const KernelInvocation *kernelInvocation) const
   NOTIFY(kernelBegin, kernelInvocation);
 }
 
-void Context::notifyKernelEnd(const KernelInvocation *kernelInvocation) const
+void Context::notifyKernelEnd(const KernelInvocation* kernelInvocation) const
 {
   NOTIFY(kernelEnd, kernelInvocation);
 
@@ -235,14 +232,14 @@ void Context::notifyKernelEnd(const KernelInvocation *kernelInvocation) const
   m_kernelInvocation = NULL;
 }
 
-void Context::notifyMemoryAllocated(const Memory *memory, size_t address,
+void Context::notifyMemoryAllocated(const Memory* memory, size_t address,
                                     size_t size, cl_mem_flags flags,
-                                    const uint8_t *initData) const
+                                    const uint8_t* initData) const
 {
   NOTIFY(memoryAllocated, memory, address, size, flags, initData);
 }
 
-void Context::notifyMemoryAtomicLoad(const Memory *memory, AtomicOp op,
+void Context::notifyMemoryAtomicLoad(const Memory* memory, AtomicOp op,
                                      size_t address, size_t size) const
 {
   if (m_kernelInvocation && m_kernelInvocation->getCurrentWorkItem())
@@ -252,7 +249,7 @@ void Context::notifyMemoryAtomicLoad(const Memory *memory, AtomicOp op,
   }
 }
 
-void Context::notifyMemoryAtomicStore(const Memory *memory, AtomicOp op,
+void Context::notifyMemoryAtomicStore(const Memory* memory, AtomicOp op,
                                       size_t address, size_t size) const
 {
   if (m_kernelInvocation && m_kernelInvocation->getCurrentWorkItem())
@@ -262,13 +259,13 @@ void Context::notifyMemoryAtomicStore(const Memory *memory, AtomicOp op,
   }
 }
 
-void Context::notifyMemoryDeallocated(const Memory *memory,
+void Context::notifyMemoryDeallocated(const Memory* memory,
                                       size_t address) const
 {
   NOTIFY(memoryDeallocated, memory, address);
 }
 
-void Context::notifyMemoryLoad(const Memory *memory, size_t address,
+void Context::notifyMemoryLoad(const Memory* memory, size_t address,
                                size_t size) const
 {
   if (m_kernelInvocation)
@@ -290,15 +287,15 @@ void Context::notifyMemoryLoad(const Memory *memory, size_t address,
   }
 }
 
-void Context::notifyMemoryMap(const Memory *memory, size_t address,
+void Context::notifyMemoryMap(const Memory* memory, size_t address,
                               size_t offset, size_t size,
                               cl_mem_flags flags) const
 {
   NOTIFY(memoryMap, memory, address, offset, size, flags);
 }
 
-void Context::notifyMemoryStore(const Memory *memory, size_t address,
-                                size_t size, const uint8_t *storeData) const
+void Context::notifyMemoryStore(const Memory* memory, size_t address,
+                                size_t size, const uint8_t* storeData) const
 {
   if (m_kernelInvocation)
   {
@@ -319,50 +316,49 @@ void Context::notifyMemoryStore(const Memory *memory, size_t address,
   }
 }
 
-void Context::notifyMessage(MessageType type, const char *message) const
+void Context::notifyMessage(MessageType type, const char* message) const
 {
   NOTIFY(log, type, message);
 }
 
-void Context::notifyMemoryUnmap(const Memory *memory, size_t address,
-                                const void *ptr) const
+void Context::notifyMemoryUnmap(const Memory* memory, size_t address,
+                                const void* ptr) const
 {
   NOTIFY(memoryUnmap, memory, address, ptr);
 }
 
-void Context::notifyWorkGroupBarrier(const WorkGroup *workGroup,
+void Context::notifyWorkGroupBarrier(const WorkGroup* workGroup,
                                      uint32_t flags) const
 {
   NOTIFY(workGroupBarrier, workGroup, flags);
 }
 
-void Context::notifyWorkGroupBegin(const WorkGroup *workGroup) const
+void Context::notifyWorkGroupBegin(const WorkGroup* workGroup) const
 {
   NOTIFY(workGroupBegin, workGroup);
 }
 
-void Context::notifyWorkGroupComplete(const WorkGroup *workGroup) const
+void Context::notifyWorkGroupComplete(const WorkGroup* workGroup) const
 {
   NOTIFY(workGroupComplete, workGroup);
 }
 
-void Context::notifyWorkItemBegin(const WorkItem *workItem) const
+void Context::notifyWorkItemBegin(const WorkItem* workItem) const
 {
   NOTIFY(workItemBegin, workItem);
 }
 
-void Context::notifyWorkItemComplete(const WorkItem *workItem) const
+void Context::notifyWorkItemComplete(const WorkItem* workItem) const
 {
   NOTIFY(workItemComplete, workItem);
 }
 
 #undef NOTIFY
 
-
-Context::Message::Message(MessageType type, const Context *context)
+Context::Message::Message(MessageType type, const Context* context)
 {
-  m_type             = type;
-  m_context          = context;
+  m_type = type;
+  m_context = context;
   m_kernelInvocation = context->m_kernelInvocation;
 }
 
@@ -371,7 +367,7 @@ Context::Message& Context::Message::operator<<(const special& id)
   switch (id)
   {
   case INDENT:
-    m_indentModifiers.push_back( m_stream.tellp());
+    m_indentModifiers.push_back(m_stream.tellp());
     break;
   case UNINDENT:
     m_indentModifiers.push_back(-m_stream.tellp());
@@ -381,7 +377,7 @@ Context::Message& Context::Message::operator<<(const special& id)
     break;
   case CURRENT_WORK_ITEM_GLOBAL:
   {
-    const WorkItem *workItem = m_kernelInvocation->getCurrentWorkItem();
+    const WorkItem* workItem = m_kernelInvocation->getCurrentWorkItem();
     if (workItem)
     {
       *this << workItem->getGlobalID();
@@ -394,7 +390,7 @@ Context::Message& Context::Message::operator<<(const special& id)
   }
   case CURRENT_WORK_ITEM_LOCAL:
   {
-    const WorkItem *workItem = m_kernelInvocation->getCurrentWorkItem();
+    const WorkItem* workItem = m_kernelInvocation->getCurrentWorkItem();
     if (workItem)
     {
       *this << workItem->getLocalID();
@@ -407,7 +403,7 @@ Context::Message& Context::Message::operator<<(const special& id)
   }
   case CURRENT_WORK_GROUP:
   {
-    const WorkGroup *workGroup = m_kernelInvocation->getCurrentWorkGroup();
+    const WorkGroup* workGroup = m_kernelInvocation->getCurrentWorkGroup();
     if (workGroup)
     {
       *this << workGroup->getGroupID();
@@ -420,18 +416,18 @@ Context::Message& Context::Message::operator<<(const special& id)
   }
   case CURRENT_ENTITY:
   {
-    const WorkItem *workItem = m_kernelInvocation->getCurrentWorkItem();
-    const WorkGroup *workGroup = m_kernelInvocation->getCurrentWorkGroup();
+    const WorkItem* workItem = m_kernelInvocation->getCurrentWorkItem();
+    const WorkGroup* workGroup = m_kernelInvocation->getCurrentWorkGroup();
     if (workItem)
     {
-      *this << "Global" << workItem->getGlobalID()
-            << " Local" << workItem->getLocalID() << " ";
+      *this << "Global" << workItem->getGlobalID() << " Local"
+            << workItem->getLocalID() << " ";
     }
     if (workGroup)
     {
       *this << "Group" << workGroup->getGroupID();
     }
-    if (!workItem && ! workGroup)
+    if (!workItem && !workGroup)
     {
       *this << "(unknown)";
     }
@@ -439,9 +435,9 @@ Context::Message& Context::Message::operator<<(const special& id)
   }
   case CURRENT_LOCATION:
   {
-    const llvm::Instruction *instruction = NULL;
-    const WorkItem *workItem = m_kernelInvocation->getCurrentWorkItem();
-    const WorkGroup *workGroup = m_kernelInvocation->getCurrentWorkGroup();
+    const llvm::Instruction* instruction = NULL;
+    const WorkItem* workItem = m_kernelInvocation->getCurrentWorkItem();
+    const WorkGroup* workGroup = m_kernelInvocation->getCurrentWorkGroup();
     if (workItem)
     {
       instruction = workItem->getCurrentInstruction();
@@ -458,8 +454,8 @@ Context::Message& Context::Message::operator<<(const special& id)
   return *this;
 }
 
-Context::Message& Context::Message::operator<<(
-  const llvm::Instruction *instruction)
+Context::Message&
+Context::Message::operator<<(const llvm::Instruction* instruction)
 {
   // Use mutex as some part of LLVM used by dumpInstruction() is not thread-safe
   static std::mutex mtx;
@@ -472,25 +468,25 @@ Context::Message& Context::Message::operator<<(
     *this << endl;
 
     // Output debug information
-    llvm::MDNode *md = instruction->getMetadata("dbg");
+    llvm::MDNode* md = instruction->getMetadata("dbg");
     if (!md)
     {
       *this << "Debugging information not available." << endl;
     }
     else
     {
-      llvm::DILocation *loc = (llvm::DILocation*)md;
+      llvm::DILocation* loc = (llvm::DILocation*)md;
       unsigned lineNumber = loc->getLine();
       unsigned columnNumber = loc->getColumn();
       llvm::StringRef filename = loc->getFilename();
 
-      *this << "At line " << dec << lineNumber
-            << " (column " << columnNumber << ")"
+      *this << "At line " << dec << lineNumber << " (column " << columnNumber
+            << ")"
             << " of " << filename.str() << ":" << endl;
 
       // Get source line
-      const Program *program = m_kernelInvocation->getKernel()->getProgram();
-      const char *line = program->getSourceLine(lineNumber);
+      const Program* program = m_kernelInvocation->getKernel()->getProgram();
+      const char* line = program->getSourceLine(lineNumber);
       if (line)
       {
         while (isspace(line[0]))
@@ -499,7 +495,6 @@ Context::Message& Context::Message::operator<<(
       }
       else
         *this << "  (source not available)";
-
     }
   }
   else
@@ -510,22 +505,21 @@ Context::Message& Context::Message::operator<<(
   return *this;
 }
 
-Context::Message& Context::Message::operator<<(
-  std::ostream& (*t)(std::ostream&))
+Context::Message&
+Context::Message::operator<<(std::ostream& (*t)(std::ostream&))
 {
   m_stream << t;
   return *this;
 }
 
-Context::Message& Context::Message::operator<<(
-  std::ios& (*t)(std::ios&))
+Context::Message& Context::Message::operator<<(std::ios& (*t)(std::ios&))
 {
   m_stream << t;
   return *this;
 }
 
-Context::Message& Context::Message::operator<<(
-  std::ios_base& (*t)(std::ios_base&))
+Context::Message&
+Context::Message::operator<<(std::ios_base& (*t)(std::ios_base&))
 {
   m_stream << t;
   return *this;
@@ -545,6 +539,10 @@ void Context::Message::send() const
   {
     getline(m_stream, line);
 
+    // Strip trailing carriage return if present
+    if (!line.empty() && line[line.size() - 1] == '\r')
+      line.pop_back();
+
     // TODO: Wrap long lines
     msg += line;
 
