@@ -10,18 +10,18 @@
 
 namespace oclgrind
 {
-  class Logger : public Plugin
-  {
-  public:
-    Logger(const Context *context);
-    virtual ~Logger();
+class Logger : public Plugin
+{
+public:
+  Logger(const Context* context);
+  virtual ~Logger();
 
-    virtual void log(MessageType type, const char *message) override;
+  virtual void log(MessageType type, const char* message) override;
 
-  private:
-    std::ostream *m_log;
+private:
+  std::ostream* m_log;
 
-    unsigned m_maxErrors;
-    static unsigned m_numErrors;
-  };
-}
+  unsigned m_maxErrors;
+  static unsigned m_numErrors;
+};
+} // namespace oclgrind
